summaryrefslogtreecommitdiff
path: root/lib/curl_sasl.c
diff options
context:
space:
mode:
authorSteve Holme <steve_holme@hotmail.com>2015-08-31 11:45:47 +0100
committerSteve Holme <steve_holme@hotmail.com>2015-08-31 12:43:58 +0100
commitb85043799157e761aa23d7b96a4721ef3b5e4598 (patch)
tree3e3f8ce2dc77732f333c80ea00b2aaad1cd9d217 /lib/curl_sasl.c
parenteb8283bb1ad0dd5c826f6b1791e30a6af4b412ae (diff)
downloadcurl-b85043799157e761aa23d7b96a4721ef3b5e4598.tar.gz
sasl: Updated SPN variables and comments for consistency
In places the "host name" and "realm" variable was referred to as "instance" whilst in others it was referred to as "host".
Diffstat (limited to 'lib/curl_sasl.c')
-rw-r--r--lib/curl_sasl.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/curl_sasl.c b/lib/curl_sasl.c
index 68646bc1a..8c97c10f1 100644
--- a/lib/curl_sasl.c
+++ b/lib/curl_sasl.c
@@ -263,19 +263,19 @@ static CURLcode sasl_digest_get_qop_values(const char *options, int *value)
/*
* Curl_sasl_build_spn()
*
* This is used to build a SPN string in the format service/host.
*
* Parameters:
*
* service [in] - The service type such as www, smtp, pop or imap.
* host [in] - The host name or realm.
*
* Returns a pointer to the newly allocated SPN.
*/
-char *Curl_sasl_build_spn(const char *service, const char *host)
+char *Curl_sasl_build_spn(const char *service, const char *instance)
{
/* Generate and return our SPN */
- return aprintf("%s/%s", service, host);
+ return aprintf("%s/%s", service, instance);
}
#endif
@@ -263,19 +263,19 @@ static CURLcode sasl_digest_get_qop_values(const char *options, int *value)
* Curl_sasl_build_spn()
*
- * This is used to build a SPN string in the format service/host.
+ * This is used to build a SPN string in the format service/instance.
*
* Parameters:
@@ -263,19 +263,19 @@ static CURLcode sasl_digest_get_qop_values(const char *options, int *value)
*
* service [in] - The service type such as www, smtp, pop or imap.
- * host [in] - The host name or realm.
+ * instance [in] - The host name or realm.
*
* Returns a pointer to the newly allocated SPN.